@@ -34,9 +34,6 @@
     
 ======================================================================*/
 
-#include <pcmcia/config.h>
-#include <pcmcia/k_compat.h>
-
 #include <linux/module.h>
 #include <linux/init.h>
 #include <linux/kernel.h>
