@@ -8,10 +8,18 @@
 #define __initdata
 #define __exit
 #define __exitdata
+#define __devinit
+#define __devinitdata
+#define __devexit
+#define __devexitdata
 #define module_init(x) int init_module(void) { return x(); }
 #define module_exit(x) void cleanup_module(void) { x(); }
 #else
 #include_next <linux/init.h>
 #endif
 
+#ifndef __devexit_p
+#define __devexit_p(x) (x)
+#endif
+
 #endif /* _COMPAT_INIT_H */
