@@ -2,7 +2,7 @@
 
     Kernel fixups for PCI device support
     
-    pci_fixup.c 1.28 2001/08/06 01:29:28
+    pci_fixup.c 1.33 2002/10/12 19:02:59
     
     PCI bus fixups: various bits of code that don't really belong in
     the PCMCIA subsystem, but may or may not be available from the
@@ -11,9 +11,7 @@
 
 ======================================================================*/
 
-#include <pcmcia/config.h>
 #define __NO_VERSION__
-#include <pcmcia/k_compat.h>
 
 #include <linux/module.h>
 #include <linux/kernel.h>
@@ -25,6 +23,7 @@
 #include "yenta.h"
 #include "i82365.h"
 
+#define VERSION KERNEL_VERSION
 #if (LINUX_VERSION_CODE < VERSION(2,3,24))
 
 /* Default memory base addresses for CardBus controllers */
@@ -250,13 +249,15 @@ static u8 cyrix_link(struct pci_dev *router, u8 link)
 {
     u8 pirq;
     /* link should be 1, 2, 3, 4 */
-    pci_read_config_byte(router, 0x5c + ((link-1)>>1), &pirq);
+    link--;
+    pci_read_config_byte(router, 0x5c + (link>>1), &pirq);
     return ((link & 1) ? pirq >> 4 : pirq & 15);
 }
 
 static void cyrix_init(struct pci_dev *router, u8 link, u8 irq)
 {
     u8 pirq;
+    link--;
     pci_read_config_byte(router, 0x5c + (link>>1), &pirq);
     pirq &= (link & 1) ? 0x0f : 0xf0;
     pirq |= (link & 1) ? (irq << 4) : (irq & 15);
@@ -528,9 +529,6 @@ static void setup_cb_bridge(struct pci_dev *dev)
     }
 }
 
-#define CMD_DFLT (PCI_COMMAND_IO | PCI_COMMAND_MEMORY | \
-		  PCI_COMMAND_MASTER | PCI_COMMAND_WAIT)
-
 #ifdef __i386__
 
 static u8 pirq_init(struct pci_dev *router, struct pirq_pin *pin)
@@ -582,7 +580,6 @@ static void setup_cb_bridge_irq(struct pci_dev *dev)
 
 int pci_enable_device(struct pci_dev *dev)
 {
-    pci_write_config_word(dev, PCI_COMMAND, CMD_DFLT);
     if ((dev->class >> 8) == PCI_CLASS_BRIDGE_CARDBUS) {
 	setup_cb_bridge(dev);
     }
