@@ -29,7 +29,7 @@
    Documentation is expected to be available in the week of 8 Februari 1999
 
 */
-
+#include <asm/byteorder.h>
 
 #ifndef HCFCFG_H                                                     
 #define HCFCFG_H 1
@@ -38,7 +38,7 @@
 *
 * FILE	 : hcfcfg.tpl // hcfcfg.h **************************** 2.0 ********************************************
 *
-* DATE   : 2000/01/06 23:30:52   1.2
+* DATE   : 2001/03/01 00:59:03   1.4
 *
 * AUTHOR : Nico Valster
 *
@@ -74,6 +74,12 @@
 
 /****************************************************************************
 wvlan_hcfcfg.h,v
+Revision 1.4  2001/03/01 00:59:03  root
+*** empty log message ***
+
+Revision 1.3  2000/12/13 22:58:23  root
+*** empty log message ***
+
 Revision 1.2  2000/01/06 23:30:52  root
 *** empty log message ***
 
@@ -152,9 +158,12 @@ Initial revision
  * Hint: introduce CNV_HOST_TO_NETWORK names if appropriate
  *
  */
- 
+
+#ifdef __BIG_ENDIAN
+#define HCF_BIG_ENDIAN				// selects Big Endian (a.k.a. Motorola), most significant byte first
+#else
 #define HCF_LITTLE_ENDIAN			// selects Little Endian (a.k.a. Intel), least significant byte first
-//#define HCF_BIG_ENDIAN				// selects Big Endian (a.k.a. Motorola), most significant byte first
+#endif
 
 /*	I/O Address size
  *	Platforms which use port mapped I/O will (in general) have a 64k I/O space, conveniently expressed in
@@ -252,7 +261,7 @@ Initial revision
 *
 *  NOTE!!	in the Intel environment it is O.K to have a word (as a 16 bits quantity) at a byte boundary, 
 *			hence IN_/OUT_PORT_STRING can move words between PC-memory and NIC-memory with as only
-*			constraint that the the words are on a word boundary in NIC-memory. This does not hold true
+*			constraint that the words are on a word boundary in NIC-memory. This does not hold true
 *			for all conceivalble environments, e.g. an Motorola 68xxx does not allow this, in other
 *			words whenever there is a move from address in 2*n in one memory type to address 2*m+1 in the
 *			other type, the current templates for IN_/OUT_PORT_STRING are unsuitable. Probably the
@@ -570,8 +579,6 @@ typedef unsigned long				hcf_32;
 
 #include <asm/io.h>
 
-//#define CNV_LITTLE_TO_INT(x)			// No endianess conversion needed										
-
 #define FAR							// flat 32-bits code
 #define BASED 
 
@@ -579,16 +586,13 @@ typedef unsigned char				hcf_8;
 typedef unsigned short				hcf_16;
 typedef unsigned long				hcf_32;
 
-#define IN_PORT_BYTE(port)			((hcf_8)inb( (hcf_io)(port) ))
-#define IN_PORT_WORD(port)			((hcf_16)inw( (hcf_io)(port) ))
-#define OUT_PORT_BYTE(port, value)	(outb( (hcf_8) (value), (hcf_io)(port) ))
-#define OUT_PORT_WORD(port, value)	(outw( (hcf_16) (value), (hcf_io)(port) ))
+#define IN_PORT_BYTE(port)		((hcf_8)inb((hcf_io)(port)))
+#define IN_PORT_WORD(port)		((hcf_16)inw((hcf_io)(port)))
+#define OUT_PORT_BYTE(port, value)	outb((hcf_8)(value), (hcf_io)(port))
+#define OUT_PORT_WORD(port, value)	outw((hcf_16)(value), (hcf_io)(port))
 
-#ifdef	toch_maar_asm
-#else
-#define IN_PORT_STRING( prt, dst, n)	while ( n-- ) { *(hcf_16 FAR*)dst = IN_PORT_WORD( prt ); dst += 2; }
-#define OUT_PORT_STRING( prt, src, n)	while ( n-- ) { OUT_PORT_WORD( prt, *(hcf_16 FAR*)src ) ; src  += 2; }
-#endif	//toch_maar_asm
+#define IN_PORT_STRING			insw
+#define OUT_PORT_STRING			outsw
 
 #endif	/* LINUX */
 
@@ -1052,7 +1056,7 @@ EXTERN_C void msf_assert ( wci_bufp file_namep, unsigned int line_number, hcf_16
  *	
  *	The routines ips and ops (short for InPutString and OutPutString) are created to use the 
  *	compiler to do the type checking. It turned out that it is too easy to accidentally pass
- *	a word pointer to the the macros IN_PORT_STRING and OUT_PORT_STRING rather than a byte pointer.
+ *	a word pointer to the macros IN_PORT_STRING and OUT_PORT_STRING rather than a byte pointer.
  *	The "+2" as some macro implementations use, does not have the intended effect in those cases.
  *	The HCF_STRICT business can be ignored by MSF programmers.
  *	
